@@ -37,8 +37,6 @@ class BaseSpider(Thread):
         if item_filter:
             setattr(settings, 'ITEM_FILTER', item_filter)
 
-        self._thread_count = thread_count or settings.SPIDER_THREAD_COUNT  # 线程数
-
         # 获取队列
         queue_module = settings.REQUEST_QUEUE[settings.SPIDER_TYPE][settings.REQUEST_MODE]
         self._queue = import_module(queue_module)[0]  # 存储 请求
@@ -233,7 +231,7 @@ class BaseSpider(Thread):
 
             # 启动对应的线程
             Parser.from_settings()
-            for i in range(self._thread_count):
+            for i in range(settings.SPIDER_THREAD_COUNT):
                 parser = Parser(q=self._queue, q_item=self._queue_item, spider=self)
                 self._parser_list.append(parser)
                 parser.start()
@@ -249,7 +247,8 @@ class BaseSpider(Thread):
             self.wait_parser_done()
 
             # 等待 item buffer 执行完毕
-            self.wait_item_buffer_done()
+            if settings.SPIDER_TYPE == 1 or (settings.SPIDER_TYPE == 2 and self.spider_master):
+                self.wait_item_buffer_done()
 
             logger.debug("无任务，爬虫结束")
 
